@@ -162,19 +162,28 @@ setMethod("nrow","Dna", function(x)
 
 
 
-#fixing a bug in Extract, July 2016
-#Extract method for Dna objects
 
-setMethod("[","Dna", function(x,i=1:nrow(x),j=1:ncol(x),as.matrix=TRUE)
+#fixing a change in R base, adding drop argument June 2023
+
+setMethod("[", "Dna", function(x, i = 1:nrow(x), j = 1:ncol(x), as.matrix = TRUE, drop = FALSE)
 {
-    seq<-x@sequence[i,j,drop=FALSE]
-    lseq<-ncol(seq)
-    seqnames<-x@seqnames[i]
-    if(as.matrix) return(seq) else new("Dna",sequence=seq,seqlengths=rep(lseq,nrow(seq)),seqnames=seqnames)
-    
+    seq <- x@sequence[i,j,drop=FALSE]
+    lseq <- ncol(seq)
+    seqnames <- x@seqnames[i]
+
+    if(as.matrix) {
+        if(drop && (nrow(seq) == 1)) {
+            return(as.vector(seq)) # convert to vector if drop is TRUE and seq is a single row/column
+        } else {
+            return(seq) 
+        }
+    } else {
+        new("Dna", sequence=seq, seqlengths=rep(lseq, nrow(seq)), seqnames=seqnames)
+    }
 })
 
 
+
 #Extract replace method for Dna objects
 
 setReplaceMethod("[","Dna", function(x,i,j,value) 
@@ -1618,7 +1627,8 @@ pegas.amova<-function (formula, data = NULL, nperm = 1000, is.squared = FALSE)
     warning("at least one missing value in the distance object.")
     if (!is.squared)
     y <- y^2
-    if (class(y) == "dist")
+    #if (class(y) == "dist")
+    if (inherits(y,"dist"))
     y <- as.matrix(y)
     if (!is.matrix(y))
     stop("the lhs of the formula must be either a matrix or an object of class 'dist'.")
